summaryrefslogtreecommitdiff
path: root/libavformat/ffmenc.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/ffmenc.c')
-rw-r--r--libavformat/ffmenc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavformat/ffmenc.c b/libavformat/ffmenc.c
index 87a477fcbb..07876ccd4b 100644
--- a/libavformat/ffmenc.c
+++ b/libavformat/ffmenc.c
@@ -1,5 +1,5 @@
/*
* FFM (ffserver live feed) muxer
* Copyright (c) 2001 Fabrice Bellard
*
* This file is part of Libav.
@@ -242,7 +242,7 @@ static int ffm_write_trailer(AVFormatContext *s)
AVOutputFormat ff_ffm_muxer = {
.name = "ffm",
- .long_name = NULL_IF_CONFIG_SMALL("FFM (FFserver live feed) format"),
+ .long_name = NULL_IF_CONFIG_SMALL("FFM (AVserver live feed) format"),
.mime_type = "",
.extensions = "ffm",
.priv_data_size = sizeof(FFMContext),
@@ -1,5 +1,5 @@
/*
- * FFM (ffserver live feed) muxer
+ * FFM (avserver live feed) muxer
* Copyright (c) 2001 Fabrice Bellard
*